==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/WebDropdownDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemComponentEventArgsDescriptionMetadata } from "./WebDropdownItemComponentEventArgsDescriptionMetadata";
import { WebDropdownDescription } from "./WebDropdownDescription";
/**
 * @hidden
 */
var WebDropdownDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDropdownDescriptionMetadata, _super);
    function WebDropdownDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownDescriptionMetadata.b = function (a) {
        if (WebDropdownDescriptionMetadata.a == null) {
            WebDropdownDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownDescriptionMetadata.c(WebDropdownDescriptionMetadata.a);
        }
        if (a.g(WebDropdownDescriptionMetadata.a)) {
            return;
        }
        a.s(WebDropdownDescriptionMetadata.a);
        WebDropdownItemComponentEventArgsDescriptionMetadata.d(a);
    };
    WebDropdownDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Dropdown");
        a.item("KeepOpenOnSelect", "Boolean");
        a.item("Open", "Boolean");
        a.item("Placement", "ExportedType:string:DropdownPlacement");
        a.item("Placement@names", "Top;TopStart;TopEnd;Bottom;BottomStart;BottomEnd;Right;RightStart;RightEnd;Left;LeftStart;LeftEnd");
        a.item("PositionStrategy", "ExportedType:string:DropdownPositionStrategy");
        a.item("PositionStrategy@names", "Absolute;Fixed");
        a.item("ScrollStrategy", "ExportedType:string:DropdownScrollStrategy");
        a.item("ScrollStrategy@names", "Scroll;Block;Close");
        a.item("Flip", "Boolean");
        a.item("Distance", "Number:double");
        a.item("KeepOpenOnOutsideClick", "Boolean");
        a.item("SameWidth", "Boolean");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
        a.item("ChangeRef", "EventRef::change");
    };
    WebDropdownDescriptionMetadata.d = function (a) {
        WebDropdownDescriptionMetadata.b(a);
        a.u("WebDropdown", function () { return new WebDropdownDescription(); });
        a.t("WebDropdown", WebDropdownDescriptionMetadata.a);
    };
    WebDropdownDescriptionMetadata.$t = markType(WebDropdownDescriptionMetadata, 'WebDropdownDescriptionMetadata');
    WebDropdownDescriptionMetadata.a = null;
    return WebDropdownDescriptionMetadata;
}(Base));
export { WebDropdownDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebDropdownDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemComponentEventArgsDescriptionMetadata } from "./WebDropdownItemComponentEventArgsDescriptionMetadata";
import { WebDropdownDescription } from "./WebDropdownDescription";
/**
 * @hidden
 */
var WebDropdownDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebDropdownDescriptionMetadata, _super);
    function WebDropdownDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebDropdownDescriptionMetadata.b = function (a) {
        if (WebDropdownDescriptionMetadata.a == null) {
            WebDropdownDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebDropdownDescriptionMetadata.c(WebDropdownDescriptionMetadata.a);
        }
        if (a.j(WebDropdownDescriptionMetadata.a)) {
            return;
        }
        a.y(WebDropdownDescriptionMetadata.a);
        WebDropdownItemComponentEventArgsDescriptionMetadata.d(a);
    };
    WebDropdownDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:Dropdown");
        a.item("__tagNameWC", "String:igc-dropdown");
        a.item("KeepOpenOnSelect", "Boolean");
        a.item("Open", "Boolean");
        a.item("Placement", "ExportedType:string:DropdownPlacement");
        a.item("Placement@names", "Top;TopStart;TopEnd;Bottom;BottomStart;BottomEnd;Right;RightStart;RightEnd;Left;LeftStart;LeftEnd");
        a.item("PositionStrategy", "ExportedType:string:DropdownPositionStrategy");
        a.item("PositionStrategy@names", "Absolute;Fixed");
        a.item("ScrollStrategy", "ExportedType:string:DropdownScrollStrategy");
        a.item("ScrollStrategy@names", "Scroll;Block;Close");
        a.item("Flip", "Boolean");
        a.item("Distance", "Number:double");
        a.item("KeepOpenOnOutsideClick", "Boolean");
        a.item("SameWidth", "Boolean");
        a.item("Size", "ExportedType:string:SizableComponentSize");
        a.item("Size@names", "Large;Small;Medium");
        a.item("ChangeRef", "EventRef::change");
    };
    WebDropdownDescriptionMetadata.d = function (a) {
        WebDropdownDescriptionMetadata.b(a);
        a.aa("WebDropdown", function () { return new WebDropdownDescription(); });
        a.z("WebDropdown", WebDropdownDescriptionMetadata.a);
    };
    WebDropdownDescriptionMetadata.$t = markType(WebDropdownDescriptionMetadata, 'WebDropdownDescriptionMetadata');
    WebDropdownDescriptionMetadata.a = null;
    return WebDropdownDescriptionMetadata;
}(Base));
export { WebDropdownDescriptionMetadata };
